# feeluown-core

[![Documentation Status](https://readthedocs.org/projects/feeluown-core/badge/?version=latest)](http://feeluown-core.readthedocs.org)
[![Build Status](https://travis-ci.org/cosven/feeluown-core.svg?branch=master)](https://travis-ci.org/cosven/feeluown-core)
[![Coverage Status](https://coveralls.io/repos/github/cosven/feeluown-core/badge.svg?branch=master&service=github)](https://coveralls.io/github/cosven/feeluown-core?branch=master)
[![PyPI](https://img.shields.io/pypi/v/fuocore.svg)](https://pypi.python.org/pypi/fuocore)
[![python](https://img.shields.io/pypi/pyversions/fuocore.svg)](https://pypi.python.org/pypi/fuocore)

fuocore 提供了音乐播放器依赖的一些常见模块，
它主要是为 [feeluown](https://github.com/cosven/feeluown) 播放器而设计的，
所以名字为 fuocore，意为 feeluown core。理论上其它音乐播放器也可以使用 fuocore 作为其基础模块。

[👉 详细文档](https://feeluown-core.readthedocs.io)
